News for shuft
==============

This file lists the major changes between versions. For a more detailed list of
every change, see the Git log.

Latest
------
* tbd

1.1.0
-----
* Patch: Added support and testing for Python 3.7

1.0.4
-----
* Patch: Fixed commandline execution.
* Patch: Added better error output upon failures.

1.0.3
-----
* Patch: Fixed commandline execution.

1.0.2
-----
* Patch: Packaginig fixes.

1.0.1
-----
* Patch: Packaginig fixes.

1.0.0
-----
* Initial release.
